@@ -15,6 +15,9 @@ YELLOW = 'rgb(221,213,51)'
 YELLOW_NUM = (221,213,51)
 
 WHITE = 'rgb(255,255,255)'
+WHITE_NUM = (255,255,255)
 BLACK = 'rgb(0,0,0)'
 
+GREY = 'rgb(223, 210, 213)'
+GREY_NUM = (192, 196, 199)
 TRACE_COLORS = [TEAL_NUM, ORANGE_NUM, GREEN_NUM]
