@@ -1,6 +1,6 @@
-from PySide import QtGui
+from PySide import QtGui, QtCore
 from pyrf.units import M
-
+from pyrf.gui.fonts import GROUP_BOX_FONT
 from pyrf.gui.util import clear_layout
 from pyrf.gui.widgets import (QComboBoxPlayback, QCheckBoxPlayback,
     QDoubleSpinBoxPlayback)
@@ -22,7 +22,7 @@ class DeviceControls(QtGui.QGroupBox):
         self.controller = controller
         controller.device_change.connect(self.device_changed)
         controller.state_change.connect(self.state_changed)
-
+        self.setStyleSheet(GROUP_BOX_FONT)
         self.setTitle(name)
 
         self._create_controls()
@@ -75,12 +75,10 @@ class DeviceControls(QtGui.QGroupBox):
         self._ifgain_label = QtGui.QLabel("IF Gain:")
         self._ifgain_box = QtGui.QSpinBox()
         self._ifgain_box.setToolTip("Choose IF Gain setting")
+        # FIXME: use values from device properties
         self._ifgain_box.setRange(-10, 25)
         self._ifgain_box.setSuffix(" dB")
 
-        self._attenuator_box = QCheckBoxPlayback("Attenuator")
-        self._attenuator_box.setChecked(True)
-
         self._pll_label = QtGui.QLabel("PLL Ref:")
         self._pll_box = QComboBoxPlayback()
         self._pll_box.setToolTip("Choose PLL Reference")
@@ -89,6 +87,26 @@ class DeviceControls(QtGui.QGroupBox):
         self._level_trigger = QCheckBoxPlayback("Level Trigger")
         self._level_trigger.setToolTip("Enable Frequency Level Triggers")
 
+        self._trig_fstart_label = QtGui.QLabel("Start:")
+        self._trig_fstart = QDoubleSpinBoxPlayback()
+        # FIXME: use values from device properties
+        self._trig_fstart.setRange(0, 20000)
+        self._trig_fstart.setSuffix(" MHz")
+        self._trig_fstart.lineEdit().setReadOnly(True)
+
+        self._trig_fstop_label = QtGui.QLabel("Stop:")
+        self._trig_fstop = QDoubleSpinBoxPlayback()
+        # FIXME: use values from device properties
+        self._trig_fstop.setRange(0, 20000)
+        self._trig_fstop.setSuffix(" MHz")
+        self._trig_fstop.lineEdit().setReadOnly(True)
+
+        self._trig_amp_label = QtGui.QLabel("Level:")
+        self._trig_amp = QDoubleSpinBoxPlayback()
+        self._trig_amp.setSuffix(" dBm")
+        self._trig_amp.setRange(-2000, 2000)
+        self._trig_amp.lineEdit().setReadOnly(True)
+
     def _build_layout(self, dut_prop=None):
         features = dut_prop.SWEEP_SETTINGS if dut_prop else []
 
@@ -105,8 +123,6 @@ class DeviceControls(QtGui.QGroupBox):
         grid.addWidget(self._fshift_label, 1, 3, 1, 1)
         grid.addWidget(self._fshift_edit, 1, 4, 1, 1)
 
-        grid.addWidget(self._level_trigger, 2, 0, 1, 2)
-
         # 4k features
         if 'antenna' in features:
             grid.addWidget(self._antenna_label, 2, 3, 1, 1)
@@ -122,15 +138,25 @@ class DeviceControls(QtGui.QGroupBox):
 
         # 5k features
         if 'attenuator' in features:
-            grid.addWidget(self._attenuator_box, 2, 3, 1, 2)
-
-            # FIXME: 'pll_reference' isn't in device properties yet
-            grid.addWidget(self._pll_label, 3, 0, 1, 1)
-            grid.addWidget(self._pll_box, 3, 1, 1, 1)
 
             # FIXME: 'iq_output' isn't in device properties yet
             grid.addWidget(self._iq_output_label, 3, 3, 1, 1)
             grid.addWidget(self._iq_output_box, 3, 4, 1, 1)
+            
+            grid.addWidget(self._pll_label, 3, 0, 1, 1)
+            grid.addWidget(self._pll_box, 3, 1, 1, 1)
+
+        grid.addWidget(self._level_trigger, 4, 0, 1, 2)
+
+        grid.addWidget(self._trig_fstart_label, 5, 0, 1, 1)
+        grid.addWidget(self._trig_fstart, 5, 1, 1, 1)
+
+        grid.addWidget(self._trig_fstop_label, 5, 3, 1, 1)
+        grid.addWidget(self._trig_fstop, 5, 4, 1, 1)
+        
+        grid.addWidget(self._trig_amp_label, 6, 0, 1, 1)
+        grid.addWidget(self._trig_amp, 6, 1, 1, 1)
+        self._trig_state(False)
 
         grid.setColumnStretch(0, 4)
         grid.setColumnStretch(1, 8)
@@ -138,7 +164,6 @@ class DeviceControls(QtGui.QGroupBox):
         grid.setColumnStretch(3, 4)
         grid.setColumnStretch(4, 8)
 
-
     def _connect_device_controls(self):
         def new_antenna():
             self.controller.apply_device_settings(antenna=
@@ -160,9 +185,6 @@ class DeviceControls(QtGui.QGroupBox):
             self.plot_state.dev_set['ifgain'] = self._ifgain_box.value()
             self.cap_dut.configure_device(self.plot_state.dev_set)
 
-        def new_attenuator():
-            self.controller.apply_device_settings(attenuator = self._attenuator_box.isChecked())
-
         def new_pll_reference():
             if self._pll_box.currentText() == 'Internal':
                 src = 'INT'
@@ -172,18 +194,22 @@ class DeviceControls(QtGui.QGroupBox):
 
         def new_iq_path():
             self.controller.apply_device_settings(
-                iq_output_path=self._iq_output_box.currentText().upper())
+                iq_output_path= str(self._iq_output_box.currentText().upper()))
 
         def new_input_mode():
             input_mode = self._mode.currentText()
             if not input_mode:
                 return
-
             self.controller.apply_settings(mode=input_mode)
+            #FIXME rfe_mode should not be in device settings dictionary
+            if self.gui_state.device_settings['iq_output_path'] == 'CONNECTOR':
+                self.controller.apply_device_settings(rfe_mode = input_mode)
 
-        def new_trigger():
+        def enable_trigger():
             trigger_settings = self.gui_state.device_settings['trigger']
             if self._level_trigger.isChecked():
+                self._trig_state(True)
+
                 start = self.gui_state.center - (self.gui_state.span / 4)
                 stop = self.gui_state.center + (self.gui_state.span / 4)
                 level = trigger_settings['amplitude']
@@ -196,7 +222,13 @@ class DeviceControls(QtGui.QGroupBox):
                                                                 'fstart': trigger_settings['fstart'],
                                                                 'fstop': trigger_settings['fstop'],
                                                                 'amplitude': trigger_settings['amplitude']})
+                self._trig_state(False)
 
+        def new_trigger():
+            self.controller.apply_device_settings(trigger = {'type': 'LEVEL',
+                                                    'fstart': self._trig_fstart.value() * M,
+                                                    'fstop': self._trig_fstop.value() * M,
+                                                    'amplitude': self._trig_amp.value()})
         def new_rbw():
             self.controller.apply_settings(rbw=self._rbw_values[
                 self._rbw_box.currentIndex()])
@@ -206,11 +238,13 @@ class DeviceControls(QtGui.QGroupBox):
         self._dec_box.currentIndexChanged.connect(new_dec)
         self._fshift_edit.valueChanged.connect(new_freq_shift)
         self._ifgain_box.valueChanged.connect(new_ifgain)
-        self._attenuator_box.clicked.connect(new_attenuator)
         self._mode.currentIndexChanged.connect(new_input_mode)
         self._iq_output_box.currentIndexChanged.connect(new_iq_path)
         self._pll_box.currentIndexChanged.connect(new_pll_reference)
-        self._level_trigger.clicked.connect(new_trigger)
+        self._level_trigger.clicked.connect(enable_trigger)
+        self._trig_fstart.valueChanged.connect(new_trigger)
+        self._trig_fstop.valueChanged.connect(new_trigger)
+        self._trig_amp.valueChanged.connect(new_trigger)
         self._rbw_box.currentIndexChanged.connect(new_rbw)
 
     def device_changed(self, dut):
@@ -219,9 +253,10 @@ class DeviceControls(QtGui.QGroupBox):
         self._update_modes()
 
 
-    def _update_modes(self):
+    def _update_modes(self, include_sweep=True):
         modes = []
-        modes.extend(self.dut_prop.SPECA_MODES)
+        if include_sweep:
+            modes.extend(self.dut_prop.SPECA_MODES)
         modes.extend(self.dut_prop.RFE_MODES)
         self._mode.quiet_update(modes)
 
@@ -236,8 +271,6 @@ class DeviceControls(QtGui.QGroupBox):
             self._dec_box.playback_value(str(state.decimation))
             self._fshift_edit.playback_value(state.fshift / M)
             self._rbw_box.playback_value(str(state.rbw))
-            self._attenuator_box.playback_value(
-                state.device_settings.get('attenuator', False))
             self._pll_box.playback_value('External'
                 if state.device_settings.get('pll_reference') == 'EXT' else
                 'Internal')
@@ -254,7 +287,6 @@ class DeviceControls(QtGui.QGroupBox):
             self._dec_box.setEnabled(decimation_available)
             self._fshift_edit.setEnabled(decimation_available)
             self._update_rbw_options()
-            self._attenuator_box.setEnabled(True)
             self._pll_box.quiet_update(["Internal", "External"])
             self._pll_box.setEnabled(True)
             self._iq_output_box.quiet_update(["Digitizer", "Connector"])
@@ -266,9 +298,12 @@ class DeviceControls(QtGui.QGroupBox):
         if 'mode' in changed:
             if state.mode not in self.dut_prop.LEVEL_TRIGGER_RFE_MODES:
                 self._level_trigger.setEnabled(False)
+
                 # forcibly disable triggers
                 if self._level_trigger.isChecked():
                     self._level_trigger.click()
+                    self.rig_state(False)
+
             else:
                 self._level_trigger.setEnabled(True)
 
@@ -290,8 +325,13 @@ class DeviceControls(QtGui.QGroupBox):
                 # remove sweep capture modes
                 self._update_modes()
                 c = self._mode.count()
-                self._mode.removeItem(0)
-                self._mode.setCurrentIndex(0)
+
+                # remove all sweep modes while using IQ out
+                self._update_modes(include_sweep=False)
+
+                if state.sweeping():
+                    self._mode.setCurrentIndex(0)
+
                 # remove all digitizer controls
                 self._rbw_label.hide()
                 self._rbw_box.hide()
@@ -306,6 +346,15 @@ class DeviceControls(QtGui.QGroupBox):
                 self._dec_box.show()
                 self._fshift_edit.show()
                 self._fshift_label.show()
+                # insert all sweep modes only if no sweep mode is in the combo box
+                self._update_modes()
+
+        if 'device_settings.trigger' in changed:
+            if state.device_settings['trigger']['type'] == 'LEVEL':
+                trigger = state.device_settings['trigger']
+                self._trig_fstart.quiet_update(value=trigger['fstart'] / M)
+                self._trig_fstop.quiet_update(value=trigger['fstop'] / M)
+                self._trig_amp.quiet_update(value=trigger['amplitude'])
 
     def _rbw_replace_items(self, items):
         for i in range(self._rbw_box.count()):
@@ -333,3 +382,9 @@ class DeviceControls(QtGui.QGroupBox):
         self._rbw_values = values
         self._rbw_box.quiet_update(
             [str(p) + ' Hz' for p in HDR_RBW_VALUES])
+
+    def _trig_state(self, state):
+        self._trig_fstart.setEnabled(state)
+        self._trig_amp.setEnabled(state)
+        self._trig_fstop.setEnabled(state)
+        self._trig = state
