@@ -30,4 +30,5 @@ def main():
     from twisted.internet import reactor
     reactor.run()
 
-
+if __name__ == "__main__":
+    main()
